@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2002, 2025, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License, version 2.0, as published by
  * the Free Software Foundation.
@@ -1717,7 +1717,7 @@ public class CallableStatementWrapper extends PreparedStatementWrapper implement
     @Override
     public <T> T getObject(int parameterIndex, Class<T> type) throws SQLException {
         if (this.wrappedStmt != null) {
-            return null; // TODO
+            return ((CallableStatement) this.wrappedStmt).getObject(parameterIndex, type);
         }
         throw SQLError.createSQLException(Messages.getString("Statement.AlreadyClosed"), MysqlErrorNumbers.SQLSTATE_CONNJ_GENERAL_ERROR,
                 this.exceptionInterceptor);
@@ -1726,7 +1726,7 @@ public class CallableStatementWrapper extends PreparedStatementWrapper implement
     @Override
     public <T> T getObject(String parameterName, Class<T> type) throws SQLException {
         if (this.wrappedStmt != null) {
-            return null; // TODO
+            return ((CallableStatement) this.wrappedStmt).getObject(parameterName, type);
         }
         throw SQLError.createSQLException(Messages.getString("Statement.AlreadyClosed"), MysqlErrorNumbers.SQLSTATE_CONNJ_GENERAL_ERROR,
                 this.exceptionInterceptor);
